altos: Switch ao_log.c and ao_log_big.c __xdata to __pdata
[fw/altos] / src / ao.h
index 08f45275fd4e51e34d3b92a2f738ea786d587782..c9a6970e8c3ac0c1ec4b39386200f3dd06d0a5bd 100644 (file)
--- a/src/ao.h
+++ b/src/ao.h
@@ -535,7 +535,7 @@ extern __pdata uint32_t ao_log_current_pos;
 extern __pdata uint32_t ao_log_end_pos;
 extern __pdata uint32_t ao_log_start_pos;
 extern __xdata uint8_t ao_log_running;
-extern __xdata enum flight_state ao_log_state;
+extern __pdata enum flight_state ao_log_state;
 
 /* required functions from the underlying log system */
 
@@ -1018,8 +1018,9 @@ struct ao_telemetry_configuration {
        uint16_t        flight;                         /*  6 flight number */
        uint8_t         config_major;                   /*  8 Config major version */
        uint8_t         config_minor;                   /*  9 Config minor version */
-       uint16_t        main_deploy;                    /* 10 Main deploy alt in meters */
-       uint32_t        flight_log_max;                 /* 12 Maximum flight log size in bytes */
+       uint16_t        apogee_delay;                   /* 10 Apogee deploy delay in seconds */
+       uint16_t        main_deploy;                    /* 12 Main deploy alt in meters */
+       uint16_t        flight_log_max;                 /* 14 Maximum flight log size in kB */
        char            callsign[AO_MAX_CALLSIGN];      /* 16 Radio operator identity */
        char            version[AO_MAX_VERSION];        /* 24 Software version */
        /* 32 */
@@ -1098,7 +1099,7 @@ union ao_telemetry_all {
 #define AO_GPS_DATE_VALID      (1 << 6)
 #define AO_GPS_COURSE_VALID    (1 << 7)
 
-extern __xdata uint16_t ao_gps_tick;
+extern __pdata uint16_t ao_gps_tick;
 extern __xdata uint8_t ao_gps_mutex;
 extern __xdata struct ao_telemetry_location ao_gps_data;
 extern __xdata struct ao_telemetry_satellite ao_gps_tracking_data;